@@ -9,13 +9,17 @@ from caluma.caluma_workflow.jexl import GroupJexl
 
 class CustomDynamicGroups(BaseDynamicGroups):
     @register_dynamic_group("admin")
-    def resolve_admin(self, task, case, user, prev_work_item):
+    def resolve_admin(self, task, case, user, prev_work_item, _context):
         return "admin-group-slug"
 
     @register_dynamic_group("staff")
-    def resolve_staff(self, task, case, user, prev_work_item):
+    def resolve_staff(self, task, case, user, prev_work_item, _context):
         return ["staff-a", "staff-b"]
 
+    @register_dynamic_group("use-context")
+    def resolve_context(self, task, case, user, prev_work_item, _context):
+        return _context["additional_groups"]
+
 
 @pytest.mark.parametrize("case__created_by_group", ["group1"])
 @pytest.mark.parametrize(
@@ -35,3 +39,24 @@ def test_dynamic_groups(
     jexl = GroupJexl(None, task, case, admin_user, work_item)
 
     assert sorted(jexl.evaluate(expression)) == sorted(expected_result)
+
+
+@pytest.mark.parametrize("case__created_by_group", ["group1"])
+@pytest.mark.parametrize(
+    "expression,expected_result", [('["use-context"]|groups', ["group1", "group2"])]
+)
+def test_dynamic_groups_context(
+    db, task, case, admin_user, work_item, expression, expected_result
+):
+    GroupJexl.dynamic_groups_classes = [CustomDynamicGroups]
+
+    jexl = GroupJexl(
+        None,
+        task,
+        case,
+        admin_user,
+        work_item,
+        dynamic_context={"additional_groups": expected_result},
+    )
+
+    assert sorted(jexl.evaluate(expression)) == sorted(expected_result)
