@@ -1,6 +1,7 @@
 import json
 
 import pytest
+from django.core.exceptions import ValidationError
 from graphene.utils.str_converters import to_const
 
 from ...caluma_core.relay import extract_global_id
@@ -443,7 +444,7 @@ def test_complete_work_item_with_next_multiple_tasks(
         2, type=models.Task.TYPE_SIMPLE
     )
     task_flow = task_flow_factory(task=task, workflow=workflow)
-    task_flow.flow.next = f"['{task_next_1.slug}', '{task_next_2.slug}']|task"
+    task_flow.flow.next = f"['{task_next_1.slug}', '{task_next_2.slug}']|tasks"
     task_flow.flow.save()
 
     query = """
@@ -498,7 +499,7 @@ def test_complete_work_item_with_next_multiple_instance_task(
         is_multiple_instance=True, address_groups=["group1", "group2", "group3"]
     )
     task_flow = task_flow_factory(task=task, workflow=workflow)
-    task_flow.flow.next = f"['{task_next.slug}']|task"
+    task_flow.flow.next = f"['{task_next.slug}']|tasks"
     task_flow.flow.save()
 
     query = """
@@ -600,17 +601,12 @@ def test_complete_work_item_with_merge(
 @pytest.mark.parametrize(
     "work_item_name,work_item_description,expected_name,expected_description",
     [
-        (
-            None,
-            None,
-            {"en": "Task name", "de": None, "fr": None},
-            {"en": "Task description", "de": None, "fr": None},
-        ),
+        (None, None, "Task name", "Task description"),
         (
             "WorkItem name",
             "WorkItem description",
-            {"en": "WorkItem name", "de": None, "fr": None},
-            {"en": "WorkItem description", "de": None, "fr": None},
+            "WorkItem name",
+            "WorkItem description",
         ),
     ],
 )
@@ -650,8 +646,8 @@ def test_save_work_item(
     work_item.refresh_from_db()
     assert work_item.assigned_users == assigned_users
     assert work_item.meta == {"test": "test"}
-    assert dict(work_item.name) == expected_name
-    assert dict(work_item.description) == expected_description
+    assert work_item.name.en == expected_name
+    assert work_item.description.en == expected_description
 
 
 @pytest.mark.parametrize(
@@ -1108,3 +1104,51 @@ def test_complete_work_item_same_task_multiple_workflows(
 
     assert case_1.status == models.Case.STATUS_RUNNING
     assert case_2.status == models.Case.STATUS_COMPLETED
+
+
+@pytest.mark.parametrize("use_graphql_api", [True, False])
+@pytest.mark.parametrize(
+    "work_item__status,success,expected_status",
+    [
+        (models.WorkItem.STATUS_READY, True, models.WorkItem.STATUS_CANCELED),
+        (models.WorkItem.STATUS_SKIPPED, False, models.WorkItem.STATUS_SKIPPED),
+    ],
+)
+def test_cancel_work_item(
+    db,
+    work_item,
+    schema_executor,
+    admin_user,
+    use_graphql_api,
+    success,
+    expected_status,
+):
+    error_msg = "Only READY work items can be cancelled"
+
+    if use_graphql_api:
+        query = """
+            mutation CancelWorkItem($input: CancelWorkItemInput!) {
+                cancelWorkItem(input: $input) {
+                    clientMutationId
+                }
+            }
+        """
+
+        result = schema_executor(query, variable_values={"input": {"id": work_item.pk}})
+
+        if success:
+            assert not bool(result.errors)
+        else:
+            assert error_msg in str(result.errors[0])
+    else:
+        if success:
+            api.cancel_work_item(work_item, admin_user)
+        else:
+            with pytest.raises(ValidationError) as error:
+                api.cancel_work_item(work_item, admin_user)
+
+            assert error_msg in str(error.value)
+
+    work_item.refresh_from_db()
+
+    assert work_item.status == expected_status
